%define	upstream_name	 IO-AIO
%define upstream_version 4.81

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 2

Summary:    Asynchronous Input/Output
License:    GPL+ or Artistic
Group:      Development/Perl
Url:        https://metacpan.org/release/%{upstream_name}
Source0:    https://cpan.metacpan.org/modules/by-module/IO/%{upstream_name}-%{upstream_version}.tar.gz
Patch0:     IO-AIO-4.4-shellbang.patch

BuildRequires: perl(Canary::Stability) >= 2001.0.0
BuildRequires: perl(ExtUtils::MakeMaker)
BuildRequires: perl(common::sense)
BuildRequires: db5.3-devel
BuildRequires: gdbm-devel
BuildRequires: perl-devel
Requires:   perl(common::sense)
%{?perl_default_filter}

%description
This module implements asynchronous I/O using whatever means your operating
system supports.

Currently, a number of threads are started that execute your read/writes and
signal their completion. You don't need thread support in your libc or perl,
and the threads created by this module will not be visible to the pthreads
library. In the future, this module might make use of the native aio functions
available on many operating systems. However, they are often not well-supported
(Linux doesn't allow them on normal files currently, for example), and they
would only support aio_read and aio_write, so the remaining functionality would
have to be implemented using threads anyway.

Although the module will work with in the presence of other threads, it is
currently not re-entrant, so use appropriate locking yourself, always call
poll_cb from within the same thread, or never call poll_cb (or other aio_
functions) recursively.

After creating a new Gtk2::Ex::Simple::List object with the desired columns you
may set the list data with a simple Perl array assignment. Rows may be added or
deleted with all of the normal array operations. You can treat the data member
of the Simple::List object as an array reference, and manipulate the list data
with perl's normal array operators.

A mechanism has also been put into place allowing columns to be Perl scalars.
The scalar is converted to text through Perl's normal mechanisms and then
displayed in the list. This same mechanism can be expanded by defining
arbitrary new column types before calling the new function.

%prep
%setup -q -n %{upstream_name}-%{upstream_version}
# Fix shellbang in treescan
%patch0

%build
PERL_CANARY_STABILITY_NOPROMPT=1 perl Makefile.PL INSTALLDIRS=vendor
%make_build CFLAGS="$RPM_OPT_FLAGS"

%install
%make_install

%check
make test

%files
%doc COPYING Changes META.json META.yml MYMETA.yml README
%{_mandir}/*/*
%{_bindir}/treescan
%{perl_vendorarch}/IO
%{perl_vendorarch}/auto/IO


%changelog
* Thu Aug 22 2024 neoclust <neoclust> 4.810.0-2.mga10
+ Revision: 2088073
- Rebuild against new perl

* Mon Feb 26 2024 tv <tv> 4.810.0-1.mga10
+ Revision: 2044366
- update to 4.81

* Tue Nov 28 2023 tv <tv> 4.800.0-2.mga10
+ Revision: 2010468
- Rebuild for perl-5.38

* Tue Aug 29 2023 tv <tv> 4.800.0-1.mga10
+ Revision: 1980979
- update to 4.8

* Wed Sep 28 2022 tv <tv> 4.790.0-1.mga9
+ Revision: 1893084
- update to 4.79

* Mon Sep 12 2022 tv <tv> 4.780.0-1.mga9
+ Revision: 1887368
- update to 4.78

* Mon Sep 05 2022 tv <tv> 4.770.0-1.mga9
+ Revision: 1884234
- update to 4.77

* Tue Jun 07 2022 umeabot <umeabot> 4.760.0-3.mga9
+ Revision: 1861996
- Rebuild for Perl 5.36

* Fri Mar 18 2022 umeabot <umeabot> 4.760.0-2.mga9
+ Revision: 1797869
- Mageia 9 Mass Rebuild

* Fri Jul 30 2021 tv <tv> 4.760.0-1.mga9
+ Revision: 1738199
- update to 4.76
- magpie doesn't like %%global ...

* Thu May 27 2021 tmb <tmb> 4.750.0-3.mga9
+ Revision: 1728657
- rebuild for perl 5.34
+ umeabot <umeabot>
- Rebuild for perl 5.34

* Thu Dec 31 2020 tv <tv> 4.750.0-1.mga8
+ Revision: 1666840
- update to 4.75

* Wed Dec 30 2020 tv <tv> 4.740.0-1.mga8
+ Revision: 1665579
- update to 4.74

* Fri Dec 04 2020 tv <tv> 4.730.0-1.mga8
+ Revision: 1652394
- update to 4.73

* Wed Jun 24 2020 tv <tv> 4.720.0-5.mga8
+ Revision: 1599123
- Fix shellbang in treescan
- do not use useless macros
+ umeabot <umeabot>
- Rebuild for perl 5.32

* Sun Feb 16 2020 umeabot <umeabot> 4.720.0-4.mga8
+ Revision: 1529508
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%makeinstall_std

* Tue Aug 27 2019 tmb <tmb> 4.720.0-3.mga8
+ Revision: 1433711
- rebuild for perl 5.30

* Tue Aug 27 2019 tv <tv> 4.720.0-2.mga8
+ Revision: 1433278
- rebuild with perl-5.30

* Thu Apr 04 2019 tv <tv> 4.720.0-1.mga7
+ Revision: 1385742
- update to 4.72

* Sun Mar 10 2019 tv <tv> 4.710.0-1.mga7
+ Revision: 1373836
- update to 4.71

* Tue Mar 05 2019 tv <tv> 4.700.0-1.mga7
+ Revision: 1371614
- update to 4.7

* Fri Sep 21 2018 umeabot <umeabot> 4.600.0-2.mga7
+ Revision: 1293193
- Mageia 7 Mass Rebuild

* Mon Aug 27 2018 tv <tv> 4.600.0-1.mga7
+ Revision: 1254849
- update to 4.6

* Tue Aug 14 2018 tv <tv> 4.540.0-1.mga7
+ Revision: 1251550
- update to 4.54

* Mon Aug 13 2018 tv <tv> 4.520.0-1.mga7
+ Revision: 1251259
- update to 4.52

* Wed Aug 08 2018 pterjan <pterjan> 4.500.0-2.mga7
+ Revision: 1249493
- Rebuild for perl 5.28

* Wed Aug 01 2018 tv <tv> 4.500.0-1.mga7
+ Revision: 1246509
- update to 4.5

* Tue Feb 20 2018 tv <tv> 4.400.0-1.mga7
+ Revision: 1203639
- update to 4.4

* Tue Oct 03 2017 tv <tv> 4.340.0-4.mga7
+ Revision: 1165013
- rebuild with fixed rpm for missing autodeps

* Tue Sep 05 2017 tv <tv> 4.340.0-3.mga7
+ Revision: 1151370
- rebuild with fixed perl

* Sat Jul 22 2017 neoclust <neoclust> 4.340.0-2.mga7
+ Revision: 1126565
- Rebuild against new Perl 5.26

* Sun May 08 2016 shlomif <shlomif> 4.340.0-1.mga6
+ Revision: 1010671
- update to 4.34

* Fri Apr 15 2016 shlomif <shlomif> 4.330.0-1.mga6
+ Revision: 1001991
- New version 4.33

* Fri Feb 12 2016 umeabot <umeabot> 4.320.0-2.mga6
+ Revision: 957543
- Mageia 6 Mass Rebuild

* Thu Jun 25 2015 sander85 <sander85> 4.320.0-1.mga6
+ Revision: 843134
- update to 4.32

* Sun Oct 19 2014 umeabot <umeabot> 4.310.0-5.mga5
+ Revision: 790017
- Rebuild to potentially add missing dependencies

* Wed Oct 15 2014 umeabot <umeabot> 4.310.0-4.mga5
+ Revision: 747899
- Second Mageia 5 Mass Rebuild

* Tue Sep 30 2014 tv <tv> 4.310.0-3.mga5
+ Revision: 732297
- add exclude

* Tue Sep 16 2014 umeabot <umeabot> 4.310.0-2.mga5
+ Revision: 685045
- Mageia 5 Mass Rebuild

* Wed Jun 04 2014 sander85 <sander85> 4.310.0-1.mga5
+ Revision: 633041
- update to 4.31

* Tue Jun 03 2014 pterjan <pterjan> 4.300.0-2.mga5
+ Revision: 631289
- Rebuild for perl 5.20

* Thu Apr 17 2014 jquelin <jquelin> 4.300.0-1.mga5
+ Revision: 615395
- update to 4.3

* Thu Feb 13 2014 jquelin <jquelin> 4.200.0-1.mga5
+ Revision: 590748
- update to 4.2

* Sat Oct 19 2013 umeabot <umeabot> 4.180.0-4.mga4
+ Revision: 524354
- Mageia 4 Mass Rebuild

* Wed May 29 2013 jquelin <jquelin> 4.180.0-3.mga4
+ Revision: 430759
- perl 5.18.0 rebuild

* Sun Jan 13 2013 umeabot <umeabot> 4.180.0-2.mga3
+ Revision: 368434
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Oct 15 2012 jquelin <jquelin> 4.180.0-1.mga3
+ Revision: 306552
- update to 4.18

* Fri Aug 24 2012 pterjan <pterjan> 4.150.0-2.mga3
+ Revision: 283462
- Rebuild for new perl

* Tue Jun 05 2012 jquelin <jquelin> 4.150.0-1.mga3
+ Revision: 255027
- update to 4.15

* Wed May 30 2012 jquelin <jquelin> 4.120.0-2.mga3
+ Revision: 250782
- rebuild for perl 5.16

* Wed Jan 04 2012 jquelin <jquelin> 4.120.0-1.mga2
+ Revision: 190316
- update to 4.12

* Fri Oct 14 2011 jquelin <jquelin> 4.110.0-1.mga2
+ Revision: 154787
- update to 4.11
- update to 4.0

* Thu Jun 30 2011 jquelin <jquelin> 3.930.0-1.mga2
+ Revision: 116426
- update to 3.93

* Wed Jun 15 2011 jquelin <jquelin> 3.900.0-1.mga2
+ Revision: 106993
- update to 3.9

* Sat Jun 11 2011 sander85 <sander85> 3.800.0-2.mga2
+ Revision: 103771
- perl 5.14

* Mon Apr 04 2011 jquelin <jquelin> 3.800.0-1.mga1
+ Revision: 80362
- update to 3.8

* Tue Jan 18 2011 jquelin <jquelin> 3.710.0-1.mga1
+ Revision: 23169
- use meta.yml
- clean spec file
- imported package perl-IO-AIO


* Fri Dec 31 2010 Guillaume Rousse <guillomovitch@mandriva.org> 3.710.0-1mdv2011.0
+ Revision: 626832
- update to new version 3.71
- update to new version 3.7

* Tue Jul 20 2010 Jérôme Quelin <jquelin@mandriva.org> 3.650.0-2mdv2011.0
+ Revision: 555962
- rebuild for perl 5.12

* Wed Mar 31 2010 Jérôme Quelin <jquelin@mandriva.org> 3.650.0-1mdv2010.1
+ Revision: 530262
- update to 3.65

* Wed Feb 10 2010 Jérôme Quelin <jquelin@mandriva.org> 3.600.0-2mdv2010.1
+ Revision: 503944
- adding missing requires:

* Mon Jan 11 2010 Jérôme Quelin <jquelin@mandriva.org> 3.600.0-1mdv2010.1
+ Revision: 489515
- update to 3.6

* Fri Jan 08 2010 Jérôme Quelin <jquelin@mandriva.org> 3.500.0-1mdv2010.1
+ Revision: 487474
- update to 3.5

* Sun Jan 03 2010 Jérôme Quelin <jquelin@mandriva.org> 3.400.0-1mdv2010.1
+ Revision: 485851
- update to 3.4

* Thu Nov 12 2009 Jérôme Quelin <jquelin@mandriva.org> 3.310.0-1mdv2010.1
+ Revision: 465167
- update to 3.31

* Tue Aug 11 2009 Jérôme Quelin <jquelin@mandriva.org> 3.300.0-1mdv2010.0
+ Revision: 415038
- adding missing buildrequires:
- update to 3.3

* Fri Jul 03 2009 Guillaume Rousse <guillomovitch@mandriva.org> 3.261-1mdv2010.0
+ Revision: 391950
- update to new version 3.261

* Wed Jul 01 2009 Guillaume Rousse <guillomovitch@mandriva.org> 3.26-1mdv2010.0
+ Revision: 391184
- update to new version 3.26

* Sun Jun 28 2009 Guillaume Rousse <guillomovitch@mandriva.org> 3.25-1mdv2010.0
+ Revision: 390341
- update to new version 3.25

* Sun Jun 21 2009 Guillaume Rousse <guillomovitch@mandriva.org> 3.23-1mdv2010.0
+ Revision: 387779
- new version

* Fri May 01 2009 Guillaume Rousse <guillomovitch@mandriva.org> 3.19-1mdv2010.0
+ Revision: 370132
- update to new version 3.19

* Sat Nov 22 2008 Guillaume Rousse <guillomovitch@mandriva.org> 3.17-1mdv2009.1
+ Revision: 305728
- update to new version 3.17

* Thu Oct 23 2008 Guillaume Rousse <guillomovitch@mandriva.org> 3.16-1mdv2009.1
+ Revision: 296793
- update to new version 3.16

* Fri Oct 17 2008 Guillaume Rousse <guillomovitch@mandriva.org> 3.15-1mdv2009.1
+ Revision: 294655
- update to new version 3.15

* Sun Aug 10 2008 Guillaume Rousse <guillomovitch@mandriva.org> 3.07-1mdv2009.0
+ Revision: 270387
- update to new version 3.07

* Wed Jul 16 2008 Guillaume Rousse <guillomovitch@mandriva.org> 3.06-1mdv2009.0
+ Revision: 236266
- update to new version 3.06

* Mon Jun 23 2008 Guillaume Rousse <guillomovitch@mandriva.org> 3.05-1mdv2009.0
+ Revision: 227972
- update to new version 3.05

* Thu Jun 19 2008 Guillaume Rousse <guillomovitch@mandriva.org> 3.04-1mdv2009.0
+ Revision: 226193
- update to new version 3.04

* Fri May 30 2008 Guillaume Rousse <guillomovitch@mandriva.org> 3.03-1mdv2009.0
+ Revision: 213357
- update to new version 3.03

* Tue May 20 2008 Oden Eriksson <oeriksson@mandriva.com> 3.02-2mdv2009.0
+ Revision: 209548
- get rid of the db1-devel and db2-devel build deps, db4-devel is enough

* Tue May 20 2008 Guillaume Rousse <guillomovitch@mandriva.org> 3.02-1mdv2009.0
+ Revision: 209316
- fix build dependencies
- update to new version 3.02

* Tue May 06 2008 Guillaume Rousse <guillomovitch@mandriva.org> 2.62-1mdv2009.0
+ Revision: 201970
- update to new version 2.62

* Thu Apr 17 2008 Guillaume Rousse <guillomovitch@mandriva.org> 2.61-1mdv2009.0
+ Revision: 195434
- update to new version 2.61

* Mon Jan 14 2008 Pixel <pixel@mandriva.com> 2.51-2mdv2008.1
+ Revision: 151422
- rebuild for perl-5.10.0

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Sat Oct 13 2007 Guillaume Rousse <guillomovitch@mandriva.org> 2.51-1mdv2008.1
+ Revision: 98033
- update to new version 2.51
- update to new version 2.51


* Tue Mar 06 2007 Guillaume Rousse <guillomovitch@mandriva.org> 2.33-1mdv2007.0
+ Revision: 133706
- new version

* Thu Nov 16 2006 Guillaume Rousse <guillomovitch@mandriva.org> 2.2-1mdv2007.1
+ Revision: 84622
- new version
- Import perl-IO-AIO

* Fri Sep 01 2006 Guillaume Rousse <guillomovitch@mandriva.org> 1.73-2mdv2007.0
- Rebuild

* Thu Mar 02 2006 Guillaume Rousse <guillomovitch@mandriva.org> 1.73-1mdk
- New release 1.73

* Thu Feb 09 2006 Guillaume Rousse <guillomovitch@mandriva.org> 1.72-1mdk
- New release 1.72

* Thu Dec 29 2005 Guillaume Rousse <guillomovitch@mandriva.org> 1.71-1mdk
- New release 1.71
- use correct compilation flags

* Tue Dec 20 2005 Guillaume Rousse <guillomovitch@mandriva.org> 1.61-1mdk
- first mdk release

